#!/usr/bin/env python
# coding: utf-8
import numpy as np
import math
from qiskit import(
QuantumCircuit,
QuantumRegister,
ClassicalRegister,
execute,
Aer)
from qiskit.visualization import plot_histogram
from qiskit.quantum_info.operators import Operator

input_quantum_state = [ 1/math.sqrt(15), 
                        -2/math.sqrt(15), 
                        3/math.sqrt(15), 
                        -complex(0,1)/math.sqrt(15)
                      ]

# Define circuit with 3 qubits and 3 classical registers
q = QuantumRegister(3)
c = ClassicalRegister(3)
circuit = QuantumCircuit(q,c)
circuit.initialize(input_quantum_state, [q[0],q[1]]) 

circuit.h([q[0],q[2]]) 
circuit.cx(0,1)
circuit.h(0)
circuit.cx(2,1)
circuit.measure(q, c) 

circuit.draw(output='mpl')

circuit.num_unitary_factors()

backend = Aer.get_backend('qasm_simulator')

# Define the run parameters and execute
job = execute( circuit, backend, shots=1024 )

# Tally the results
collapsed_states_array = job.result().get_counts()
print(collapsed_states_array)

plot_histogram( collapsed_states_array )

