#!/usr/bin/env python
# coding: utf-8

# Header lines - import libraries
import numpy as np
import math
from qiskit import(
QuantumCircuit,
QuantumRegister,
ClassicalRegister,
execute,
Aer)
from qiskit.visualization import plot_histogram

# Define circuit
circuit = QuantumCircuit()

# Declare and add quantum and classical registers
q = QuantumRegister(2,'qreg') # 2 Qubits Register
circuit.add_register( q )

c = ClassicalRegister(2,'creg') # 2 Bits Classical Register
circuit.add_register(c)

# Declare the H Gate
circuit.h(q[0]) 

# Declare the CNOT Gate
circuit.cnot(q[0],q[1])

# Collapse Qubits
circuit.measure(q[0],c[0])
circuit.measure(q[1],c[1]) 

# Draw the circuit
circuit.draw(output='mpl')

# Use simulator to run the circuit
backend = Aer.get_backend('qasm_simulator')

# Define the run parameters and execute
job = execute( circuit, backend, shots=1024 )

# Tally the results
hist = job.result().get_counts()

# Plot the histogram of quantum states
plot_histogram( hist )
